%%
%% %CopyrightBegin%
%%
%% SPDX-License-Identifier: Apache-2.0 AND LicenseRef-scancode-wxwindows-free-doc-3
%%
%% Copyright Ericsson AB 2008-2025. All Rights Reserved.
%%
%% Licensed under the Apache License, Version 2.0 (the "License");
%% you may not use this file except in compliance with the License.
%% You may obtain a copy of the License at
%%
%%     http://www.apache.org/licenses/LICENSE-2.0
%%
%% Unless required by applicable law or agreed to in writing, software
%% distributed under the License is distributed on an "AS IS" BASIS,
%% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
%% See the License for the specific language governing permissions and
%% limitations under the License.
%%
%% For documentation, wxWindow Free Documentation License, Version 3 applies.
%% wxWindows Free Documentation Licence, Version 3, as follows.
%% ===============================================
%%
%% Everyone is permitted to copy and distribute verbatim copies
%% of this licence document, but changing it is not allowed.
%%
%%                  WXWINDOWS FREE DOCUMENTATION LICENCE
%%    TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
%%
%% 1. Permission is granted to make and distribute verbatim copies of this
%% manual or piece of documentation provided any copyright notice and this
%% permission notice are preserved on all copies.
%%
%% 2. Permission is granted to process this file or document through a
%% document processing system and, at your option and the option of any third
%% party, print the results, provided a printed document carries a copying
%% permission notice identical to this one.
%%
%% 3. Permission is granted to copy and distribute modified versions of this
%% manual or piece of documentation under the conditions for verbatim copying,
%% provided also that any sections describing licensing conditions for this
%% manual, such as, in particular, the GNU General Public Licence, the GNU
%% Library General Public Licence, and any wxWindows Licence are included
%% exactly as in the original, and provided that the entire resulting derived
%% work is distributed under the terms of a permission notice identical to
%% this one.
%%
%% 4. Permission is granted to copy and distribute translations of this manual
%% or piece of documentation into another language, under the above conditions
%% for modified versions, except that sections related to licensing, including
%% this paragraph, may also be included in translations approved by the
%% copyright holders of the respective licence documents in addition to the
%% original English.
%%
%% %CopyrightEnd%
%% This file is generated DO NOT EDIT

-module(wxAuiNotebook).
-moduledoc """
`m:wxAuiNotebook` is part of the wxAUI class framework, which represents a notebook
control, managing multiple windows with associated tabs.

See also overview_aui.

`m:wxAuiNotebook` is a notebook control which implements many features common in
applications with dockable panes. Specifically, `m:wxAuiNotebook` implements functionality
which allows the user to rearrange tab order via drag-and-drop, split the tab window into
many different splitter configurations, and toggle through different themes to customize
the control's look and feel.

The default theme that is used is `wxAuiDefaultTabArt` (not implemented in wx), which
provides a modern, glossy look and feel. The theme can be changed by calling `setArtProvider/2`.

## Styles

This class supports the following styles:

* wxAUI_NB_DEFAULT_STYLE: Defined as wxAUI_NB_TOP | wxAUI_NB_TAB_SPLIT | wxAUI_NB_TAB_MOVE
| wxAUI_NB_SCROLL_BUTTONS | wxAUI_NB_CLOSE_ON_ACTIVE_TAB | wxAUI_NB_MIDDLE_CLICK_CLOSE.

* wxAUI_NB_TAB_SPLIT: Allows the tab control to be split by dragging a tab.

* wxAUI_NB_TAB_MOVE: Allows a tab to be moved horizontally by dragging.

* wxAUI_NB_TAB_EXTERNAL_MOVE: Allows a tab to be moved to another tab control.

* wxAUI_NB_TAB_FIXED_WIDTH: With this style, all tabs have the same width.

* wxAUI_NB_SCROLL_BUTTONS: With this style, left and right scroll buttons are displayed.

* wxAUI_NB_WINDOWLIST_BUTTON: With this style, a drop-down list of windows is available.

* wxAUI_NB_CLOSE_BUTTON: With this style, a close button is available on the tab bar.

* wxAUI_NB_CLOSE_ON_ACTIVE_TAB: With this style, the close button is visible on the active
tab.

* wxAUI_NB_CLOSE_ON_ALL_TABS: With this style, the close button is visible on all tabs.

* wxAUI_NB_MIDDLE_CLICK_CLOSE: With this style, middle click on a tab closes the tab.

* wxAUI_NB_TOP: With this style, tabs are drawn along the top of the notebook.

* wxAUI_NB_BOTTOM: With this style, tabs are drawn along the bottom of the notebook.

This class is derived, and can use functions, from:

* `m:wxControl`

* `m:wxWindow`

* `m:wxEvtHandler`

wxWidgets docs: [wxAuiNotebook](https://docs.wxwidgets.org/3.2/classwx_aui_notebook.html)

## Events

Event types emitted from this class:

* [`command_auinotebook_page_close`](`m:wxAuiNotebookEvent`)

* [`command_auinotebook_page_closed`](`m:wxAuiNotebookEvent`)

* [`command_auinotebook_page_changed`](`m:wxAuiNotebookEvent`)

* [`command_auinotebook_page_changing`](`m:wxAuiNotebookEvent`)

* [`command_auinotebook_button`](`m:wxAuiNotebookEvent`)

* [`command_auinotebook_begin_drag`](`m:wxAuiNotebookEvent`)

* [`command_auinotebook_end_drag`](`m:wxAuiNotebookEvent`)

* [`command_auinotebook_drag_motion`](`m:wxAuiNotebookEvent`)

* [`command_auinotebook_allow_dnd`](`m:wxAuiNotebookEvent`)

* [`command_auinotebook_drag_done`](`m:wxAuiNotebookEvent`)

* [`command_auinotebook_tab_middle_down`](`m:wxAuiNotebookEvent`)

* [`command_auinotebook_tab_middle_up`](`m:wxAuiNotebookEvent`)

* [`command_auinotebook_tab_right_down`](`m:wxAuiNotebookEvent`)

* [`command_auinotebook_tab_right_up`](`m:wxAuiNotebookEvent`)

* [`command_auinotebook_bg_dclick`](`m:wxAuiNotebookEvent`)
""".
-include("wxe.hrl").
-export([addPage/3,addPage/4,addPage/5,create/2,create/3,create/4,deletePage/2,
  destroy/1,getArtProvider/1,getPage/2,getPageBitmap/2,getPageCount/1,
  getPageIndex/2,getPageText/2,getSelection/1,insertPage/4,insertPage/5,
  insertPage/6,new/0,new/1,new/2,removePage/2,setArtProvider/2,setFont/2,
  setPageBitmap/3,setPageText/3,setSelection/2,setTabCtrlHeight/2,setUniformBitmapSize/2]).

%% inherited exports
-export([cacheBestSize/2,canSetTransparent/1,captureMouse/1,center/1,center/2,
  centerOnParent/1,centerOnParent/2,centre/1,centre/2,centreOnParent/1,
  centreOnParent/2,clearBackground/1,clientToScreen/2,clientToScreen/3,
  close/1,close/2,connect/2,connect/3,convertDialogToPixels/2,convertPixelsToDialog/2,
  destroyChildren/1,disable/1,disconnect/1,disconnect/2,disconnect/3,
  dragAcceptFiles/2,enable/1,enable/2,findWindow/2,fit/1,fitInside/1,
  freeze/1,getAcceleratorTable/1,getBackgroundColour/1,getBackgroundStyle/1,
  getBestSize/1,getCaret/1,getCharHeight/1,getCharWidth/1,getChildren/1,
  getClientSize/1,getContainingSizer/1,getContentScaleFactor/1,getCursor/1,
  getDPI/1,getDPIScaleFactor/1,getDropTarget/1,getExtraStyle/1,getFont/1,
  getForegroundColour/1,getGrandParent/1,getHandle/1,getHelpText/1,
  getId/1,getLabel/1,getMaxSize/1,getMinSize/1,getName/1,getParent/1,
  getPosition/1,getRect/1,getScreenPosition/1,getScreenRect/1,getScrollPos/2,
  getScrollRange/2,getScrollThumb/2,getSize/1,getSizer/1,getTextExtent/2,
  getTextExtent/3,getThemeEnabled/1,getToolTip/1,getUpdateRegion/1,
  getVirtualSize/1,getWindowStyleFlag/1,getWindowVariant/1,hasCapture/1,
  hasScrollbar/2,hasTransparentBackground/1,hide/1,inheritAttributes/1,
  initDialog/1,invalidateBestSize/1,isDoubleBuffered/1,isEnabled/1,
  isExposed/2,isExposed/3,isExposed/5,isFrozen/1,isRetained/1,isShown/1,
  isShownOnScreen/1,isTopLevel/1,layout/1,lineDown/1,lineUp/1,lower/1,
  move/2,move/3,move/4,moveAfterInTabOrder/2,moveBeforeInTabOrder/2,
  navigate/1,navigate/2,pageDown/1,pageUp/1,parent_class/1,popupMenu/2,
  popupMenu/3,popupMenu/4,raise/1,refresh/1,refresh/2,refreshRect/2,refreshRect/3,
  releaseMouse/1,removeChild/2,reparent/2,screenToClient/1,screenToClient/2,
  scrollLines/2,scrollPages/2,scrollWindow/3,scrollWindow/4,setAcceleratorTable/2,
  setAutoLayout/2,setBackgroundColour/2,setBackgroundStyle/2,setCaret/2,
  setClientSize/2,setClientSize/3,setContainingSizer/2,setCursor/2,
  setDoubleBuffered/2,setDropTarget/2,setExtraStyle/2,setFocus/1,setFocusFromKbd/1,
  setForegroundColour/2,setHelpText/2,setId/2,setLabel/2,setMaxSize/2,
  setMinSize/2,setName/2,setOwnBackgroundColour/2,setOwnFont/2,setOwnForegroundColour/2,
  setPalette/2,setScrollPos/3,setScrollPos/4,setScrollbar/5,setScrollbar/6,
  setSize/2,setSize/3,setSize/5,setSize/6,setSizeHints/2,setSizeHints/3,
  setSizeHints/4,setSizer/2,setSizer/3,setSizerAndFit/2,setSizerAndFit/3,
  setThemeEnabled/2,setToolTip/2,setTransparent/2,setVirtualSize/2,
  setVirtualSize/3,setWindowStyle/2,setWindowStyleFlag/2,setWindowVariant/2,
  shouldInheritColours/1,show/1,show/2,thaw/1,transferDataFromWindow/1,
  transferDataToWindow/1,update/1,updateWindowUI/1,updateWindowUI/2,
  validate/1,warpPointer/3]).

-type wxAuiNotebook() :: wx:wx_object().
-export_type([wxAuiNotebook/0]).
-doc false.
parent_class(wxControl) -> true;
parent_class(wxWindow) -> true;
parent_class(wxEvtHandler) -> true;
parent_class(_Class) -> erlang:error({badtype, ?MODULE}).

-doc "Default ctor.".
-spec new() -> wxAuiNotebook().
new() ->
  wxe_util:queue_cmd(?get_env(), ?wxAuiNotebook_new_0),
  wxe_util:rec(?wxAuiNotebook_new_0).

-doc(#{equiv => new(Parent, [])}).
-spec new(Parent) -> wxAuiNotebook() when
	Parent::wxWindow:wxWindow().

new(Parent)
 when is_record(Parent, wx_ref) ->
  new(Parent, []).

-doc """
Constructor.

Creates a wxAuiNotebok control.
""".
-spec new(Parent, [Option]) -> wxAuiNotebook() when
	Parent::wxWindow:wxWindow(),
	Option :: {'id', integer()}
		 | {'pos', {X::integer(), Y::integer()}}
		 | {'size', {W::integer(), H::integer()}}
		 | {'style', integer()}.
new(#wx_ref{type=ParentT}=Parent, Options)
 when is_list(Options) ->
  ?CLASS(ParentT,wxWindow),
  MOpts = fun({id, _id} = Arg) -> Arg;
          ({pos, {_posX,_posY}} = Arg) -> Arg;
          ({size, {_sizeW,_sizeH}} = Arg) -> Arg;
          ({style, _style} = Arg) -> Arg;
          (BadOpt) -> erlang:error({badoption, BadOpt}) end,
  Opts = lists:map(MOpts, Options),
  wxe_util:queue_cmd(Parent, Opts,?get_env(),?wxAuiNotebook_new_2),
  wxe_util:rec(?wxAuiNotebook_new_2).

-doc(#{equiv => addPage(This,Page,Caption, [])}).
-spec addPage(This, Page, Caption) -> boolean() when
	This::wxAuiNotebook(), Page::wxWindow:wxWindow(), Caption::unicode:chardata().

addPage(This,Page,Caption)
 when is_record(This, wx_ref),is_record(Page, wx_ref),?is_chardata(Caption) ->
  addPage(This,Page,Caption, []).

-doc """
Adds a page.

If the `select` parameter is true, calling this will generate a page change event.
""".
-spec addPage(This, Page, Caption, [Option]) -> boolean() when
	This::wxAuiNotebook(), Page::wxWindow:wxWindow(), Caption::unicode:chardata(),
	Option :: {'select', boolean()}
		 | {'bitmap', wxBitmap:wxBitmap()}.
addPage(#wx_ref{type=ThisT}=This,#wx_ref{type=PageT}=Page,Caption, Options)
 when ?is_chardata(Caption),is_list(Options) ->
  ?CLASS(ThisT,wxAuiNotebook),
  ?CLASS(PageT,wxWindow),
  Caption_UC = unicode:characters_to_binary(Caption),
  MOpts = fun({select, _select} = Arg) -> Arg;
          ({bitmap, #wx_ref{type=BitmapT}} = Arg) ->   ?CLASS(BitmapT,wxBitmap),Arg;
          (BadOpt) -> erlang:error({badoption, BadOpt}) end,
  Opts = lists:map(MOpts, Options),
  wxe_util:queue_cmd(This,Page,Caption_UC, Opts,?get_env(),?wxAuiNotebook_AddPage_3),
  wxe_util:rec(?wxAuiNotebook_AddPage_3).

-doc """
Adds a new page.

The page must have the book control itself as the parent and must not have been added to
this control previously.

The call to this function may generate the page changing events.

Return: true if successful, false otherwise.

Remark: Do not delete the page, it will be deleted by the book control.

See: `insertPage/6`

Since: 2.9.3
""".
-spec addPage(This, Page, Text, Select, ImageId) -> boolean() when
	This::wxAuiNotebook(), Page::wxWindow:wxWindow(), Text::unicode:chardata(), Select::boolean(), ImageId::integer().
addPage(#wx_ref{type=ThisT}=This,#wx_ref{type=PageT}=Page,Text,Select,ImageId)
 when ?is_chardata(Text),is_boolean(Select),is_integer(ImageId) ->
  ?CLASS(ThisT,wxAuiNotebook),
  ?CLASS(PageT,wxWindow),
  Text_UC = unicode:characters_to_binary(Text),
  wxe_util:queue_cmd(This,Page,Text_UC,Select,ImageId,?get_env(),?wxAuiNotebook_AddPage_4),
  wxe_util:rec(?wxAuiNotebook_AddPage_4).

-doc(#{equiv => create(This,Parent, [])}).
-spec create(This, Parent) -> boolean() when
	This::wxAuiNotebook(), Parent::wxWindow:wxWindow().

create(This,Parent)
 when is_record(This, wx_ref),is_record(Parent, wx_ref) ->
  create(This,Parent, []).

-doc "Creates the notebook window.".
-spec create(This, Parent, Winid) -> boolean() when
	This::wxAuiNotebook(), Parent::wxWindow:wxWindow(), Winid::integer();
      (This, Parent, [Option]) -> boolean() when
	This::wxAuiNotebook(), Parent::wxWindow:wxWindow(),
	Option :: {'id', integer()}
		 | {'pos', {X::integer(), Y::integer()}}
		 | {'size', {W::integer(), H::integer()}}
		 | {'style', integer()}.

create(This,Parent,Winid)
 when is_record(This, wx_ref),is_record(Parent, wx_ref),is_integer(Winid) ->
  create(This,Parent,Winid, []);
create(#wx_ref{type=ThisT}=This,#wx_ref{type=ParentT}=Parent, Options)
 when is_list(Options) ->
  ?CLASS(ThisT,wxAuiNotebook),
  ?CLASS(ParentT,wxWindow),
  MOpts = fun({id, _id} = Arg) -> Arg;
          ({pos, {_posX,_posY}} = Arg) -> Arg;
          ({size, {_sizeW,_sizeH}} = Arg) -> Arg;
          ({style, _style} = Arg) -> Arg;
          (BadOpt) -> erlang:error({badoption, BadOpt}) end,
  Opts = lists:map(MOpts, Options),
  wxe_util:queue_cmd(This,Parent, Opts,?get_env(),?wxAuiNotebook_Create_2),
  wxe_util:rec(?wxAuiNotebook_Create_2).

-doc "Constructs the book control with the given parameters.".
-spec create(This, Parent, Winid, [Option]) -> boolean() when
	This::wxAuiNotebook(), Parent::wxWindow:wxWindow(), Winid::integer(),
	Option :: {'pos', {X::integer(), Y::integer()}}
		 | {'size', {W::integer(), H::integer()}}
		 | {'style', integer()}.
create(#wx_ref{type=ThisT}=This,#wx_ref{type=ParentT}=Parent,Winid, Options)
 when is_integer(Winid),is_list(Options) ->
  ?CLASS(ThisT,wxAuiNotebook),
  ?CLASS(ParentT,wxWindow),
  MOpts = fun({pos, {_posX,_posY}} = Arg) -> Arg;
          ({size, {_sizeW,_sizeH}} = Arg) -> Arg;
          ({style, _style} = Arg) -> Arg;
          (BadOpt) -> erlang:error({badoption, BadOpt}) end,
  Opts = lists:map(MOpts, Options),
  wxe_util:queue_cmd(This,Parent,Winid, Opts,?get_env(),?wxAuiNotebook_Create_3),
  wxe_util:rec(?wxAuiNotebook_Create_3).

-doc """
Deletes a page at the given index.

Calling this method will generate a page change event.
""".
-spec deletePage(This, Page) -> boolean() when
	This::wxAuiNotebook(), Page::integer().
deletePage(#wx_ref{type=ThisT}=This,Page)
 when is_integer(Page) ->
  ?CLASS(ThisT,wxAuiNotebook),
  wxe_util:queue_cmd(This,Page,?get_env(),?wxAuiNotebook_DeletePage),
  wxe_util:rec(?wxAuiNotebook_DeletePage).

-doc "Returns the associated art provider.".
-spec getArtProvider(This) -> wxAuiTabArt:wxAuiTabArt() when
	This::wxAuiNotebook().
getArtProvider(#wx_ref{type=ThisT}=This) ->
  ?CLASS(ThisT,wxAuiNotebook),
  wxe_util:queue_cmd(This,?get_env(),?wxAuiNotebook_GetArtProvider),
  wxe_util:rec(?wxAuiNotebook_GetArtProvider).

-doc "Returns the page specified by the given index.".
-spec getPage(This, Page_idx) -> wxWindow:wxWindow() when
	This::wxAuiNotebook(), Page_idx::integer().
getPage(#wx_ref{type=ThisT}=This,Page_idx)
 when is_integer(Page_idx) ->
  ?CLASS(ThisT,wxAuiNotebook),
  wxe_util:queue_cmd(This,Page_idx,?get_env(),?wxAuiNotebook_GetPage),
  wxe_util:rec(?wxAuiNotebook_GetPage).

-doc "Returns the tab bitmap for the page.".
-spec getPageBitmap(This, Page) -> wxBitmap:wxBitmap() when
	This::wxAuiNotebook(), Page::integer().
getPageBitmap(#wx_ref{type=ThisT}=This,Page)
 when is_integer(Page) ->
  ?CLASS(ThisT,wxAuiNotebook),
  wxe_util:queue_cmd(This,Page,?get_env(),?wxAuiNotebook_GetPageBitmap),
  wxe_util:rec(?wxAuiNotebook_GetPageBitmap).

-doc "Returns the number of pages in the notebook.".
-spec getPageCount(This) -> integer() when
	This::wxAuiNotebook().
getPageCount(#wx_ref{type=ThisT}=This) ->
  ?CLASS(ThisT,wxAuiNotebook),
  wxe_util:queue_cmd(This,?get_env(),?wxAuiNotebook_GetPageCount),
  wxe_util:rec(?wxAuiNotebook_GetPageCount).

-doc """
Returns the page index for the specified window.

If the window is not found in the notebook, wxNOT_FOUND is returned.
""".
-spec getPageIndex(This, Page_wnd) -> integer() when
	This::wxAuiNotebook(), Page_wnd::wxWindow:wxWindow().
getPageIndex(#wx_ref{type=ThisT}=This,#wx_ref{type=Page_wndT}=Page_wnd) ->
  ?CLASS(ThisT,wxAuiNotebook),
  ?CLASS(Page_wndT,wxWindow),
  wxe_util:queue_cmd(This,Page_wnd,?get_env(),?wxAuiNotebook_GetPageIndex),
  wxe_util:rec(?wxAuiNotebook_GetPageIndex).

-doc "Returns the tab label for the page.".
-spec getPageText(This, Page) -> unicode:charlist() when
	This::wxAuiNotebook(), Page::integer().
getPageText(#wx_ref{type=ThisT}=This,Page)
 when is_integer(Page) ->
  ?CLASS(ThisT,wxAuiNotebook),
  wxe_util:queue_cmd(This,Page,?get_env(),?wxAuiNotebook_GetPageText),
  wxe_util:rec(?wxAuiNotebook_GetPageText).

-doc "Returns the currently selected page.".
-spec getSelection(This) -> integer() when
	This::wxAuiNotebook().
getSelection(#wx_ref{type=ThisT}=This) ->
  ?CLASS(ThisT,wxAuiNotebook),
  wxe_util:queue_cmd(This,?get_env(),?wxAuiNotebook_GetSelection),
  wxe_util:rec(?wxAuiNotebook_GetSelection).

-doc(#{equiv => insertPage(This,Page_idx,Page,Caption, [])}).
-spec insertPage(This, Page_idx, Page, Caption) -> boolean() when
	This::wxAuiNotebook(), Page_idx::integer(), Page::wxWindow:wxWindow(), Caption::unicode:chardata().

insertPage(This,Page_idx,Page,Caption)
 when is_record(This, wx_ref),is_integer(Page_idx),is_record(Page, wx_ref),?is_chardata(Caption) ->
  insertPage(This,Page_idx,Page,Caption, []).

-doc """
`insertPage/6` is similar to AddPage, but allows the ability to specify the insert
location.

If the `select` parameter is true, calling this will generate a page change event.
""".
-spec insertPage(This, Page_idx, Page, Caption, [Option]) -> boolean() when
	This::wxAuiNotebook(), Page_idx::integer(), Page::wxWindow:wxWindow(), Caption::unicode:chardata(),
	Option :: {'select', boolean()}
		 | {'bitmap', wxBitmap:wxBitmap()}.
insertPage(#wx_ref{type=ThisT}=This,Page_idx,#wx_ref{type=PageT}=Page,Caption, Options)
 when is_integer(Page_idx),?is_chardata(Caption),is_list(Options) ->
  ?CLASS(ThisT,wxAuiNotebook),
  ?CLASS(PageT,wxWindow),
  Caption_UC = unicode:characters_to_binary(Caption),
  MOpts = fun({select, _select} = Arg) -> Arg;
          ({bitmap, #wx_ref{type=BitmapT}} = Arg) ->   ?CLASS(BitmapT,wxBitmap),Arg;
          (BadOpt) -> erlang:error({badoption, BadOpt}) end,
  Opts = lists:map(MOpts, Options),
  wxe_util:queue_cmd(This,Page_idx,Page,Caption_UC, Opts,?get_env(),?wxAuiNotebook_InsertPage_4),
  wxe_util:rec(?wxAuiNotebook_InsertPage_4).

-doc """
Inserts a new page at the specified position.

Return: true if successful, false otherwise.

Remark: Do not delete the page, it will be deleted by the book control.

See: `addPage/5`

Since: 2.9.3
""".
-spec insertPage(This, Index, Page, Text, Select, ImageId) -> boolean() when
	This::wxAuiNotebook(), Index::integer(), Page::wxWindow:wxWindow(), Text::unicode:chardata(), Select::boolean(), ImageId::integer().
insertPage(#wx_ref{type=ThisT}=This,Index,#wx_ref{type=PageT}=Page,Text,Select,ImageId)
 when is_integer(Index),?is_chardata(Text),is_boolean(Select),is_integer(ImageId) ->
  ?CLASS(ThisT,wxAuiNotebook),
  ?CLASS(PageT,wxWindow),
  Text_UC = unicode:characters_to_binary(Text),
  wxe_util:queue_cmd(This,Index,Page,Text_UC,Select,ImageId,?get_env(),?wxAuiNotebook_InsertPage_5),
  wxe_util:rec(?wxAuiNotebook_InsertPage_5).

-doc "Removes a page, without deleting the window pointer.".
-spec removePage(This, Page) -> boolean() when
	This::wxAuiNotebook(), Page::integer().
removePage(#wx_ref{type=ThisT}=This,Page)
 when is_integer(Page) ->
  ?CLASS(ThisT,wxAuiNotebook),
  wxe_util:queue_cmd(This,Page,?get_env(),?wxAuiNotebook_RemovePage),
  wxe_util:rec(?wxAuiNotebook_RemovePage).

-doc "Sets the art provider to be used by the notebook.".
-spec setArtProvider(This, Art) -> 'ok' when
	This::wxAuiNotebook(), Art::wxAuiTabArt:wxAuiTabArt().
setArtProvider(#wx_ref{type=ThisT}=This,#wx_ref{type=ArtT}=Art) ->
  ?CLASS(ThisT,wxAuiNotebook),
  ?CLASS(ArtT,wxAuiTabArt),
  wxe_util:queue_cmd(This,Art,?get_env(),?wxAuiNotebook_SetArtProvider).

-doc """
Sets the font for drawing the tab labels, using a bold version of the font for selected
tab labels.
""".
-spec setFont(This, Font) -> boolean() when
	This::wxAuiNotebook(), Font::wxFont:wxFont().
setFont(#wx_ref{type=ThisT}=This,#wx_ref{type=FontT}=Font) ->
  ?CLASS(ThisT,wxAuiNotebook),
  ?CLASS(FontT,wxFont),
  wxe_util:queue_cmd(This,Font,?get_env(),?wxAuiNotebook_SetFont),
  wxe_util:rec(?wxAuiNotebook_SetFont).

-doc """
Sets the bitmap for the page.

To remove a bitmap from the tab caption, pass wxNullBitmap.
""".
-spec setPageBitmap(This, Page, Bitmap) -> boolean() when
	This::wxAuiNotebook(), Page::integer(), Bitmap::wxBitmap:wxBitmap().
setPageBitmap(#wx_ref{type=ThisT}=This,Page,#wx_ref{type=BitmapT}=Bitmap)
 when is_integer(Page) ->
  ?CLASS(ThisT,wxAuiNotebook),
  ?CLASS(BitmapT,wxBitmap),
  wxe_util:queue_cmd(This,Page,Bitmap,?get_env(),?wxAuiNotebook_SetPageBitmap),
  wxe_util:rec(?wxAuiNotebook_SetPageBitmap).

-doc "Sets the tab label for the page.".
-spec setPageText(This, Page, Text) -> boolean() when
	This::wxAuiNotebook(), Page::integer(), Text::unicode:chardata().
setPageText(#wx_ref{type=ThisT}=This,Page,Text)
 when is_integer(Page),?is_chardata(Text) ->
  ?CLASS(ThisT,wxAuiNotebook),
  Text_UC = unicode:characters_to_binary(Text),
  wxe_util:queue_cmd(This,Page,Text_UC,?get_env(),?wxAuiNotebook_SetPageText),
  wxe_util:rec(?wxAuiNotebook_SetPageText).

-doc """
Sets the page selection.

Calling this method will generate a page change event.
""".
-spec setSelection(This, New_page) -> integer() when
	This::wxAuiNotebook(), New_page::integer().
setSelection(#wx_ref{type=ThisT}=This,New_page)
 when is_integer(New_page) ->
  ?CLASS(ThisT,wxAuiNotebook),
  wxe_util:queue_cmd(This,New_page,?get_env(),?wxAuiNotebook_SetSelection),
  wxe_util:rec(?wxAuiNotebook_SetSelection).

-doc """
Sets the tab height.

By default, the tab control height is calculated by measuring the text height and bitmap
sizes on the tab captions. Calling this method will override that calculation and set the
tab control to the specified height parameter. A call to this method will override any
call to `setUniformBitmapSize/2`.

Specifying -1 as the height will return the control to its default auto-sizing behaviour.
""".
-spec setTabCtrlHeight(This, Height) -> 'ok' when
	This::wxAuiNotebook(), Height::integer().
setTabCtrlHeight(#wx_ref{type=ThisT}=This,Height)
 when is_integer(Height) ->
  ?CLASS(ThisT,wxAuiNotebook),
  wxe_util:queue_cmd(This,Height,?get_env(),?wxAuiNotebook_SetTabCtrlHeight).

-doc """
Ensure that all tabs have the same height, even if some of them don't have bitmaps.

Passing ?wxDefaultSize as `size` undoes the effect of a previous call to this function
and instructs the control to use dynamic tab height.
""".
-spec setUniformBitmapSize(This, Size) -> 'ok' when
	This::wxAuiNotebook(), Size::{W::integer(), H::integer()}.
setUniformBitmapSize(#wx_ref{type=ThisT}=This,{SizeW,SizeH} = Size)
 when is_integer(SizeW),is_integer(SizeH) ->
  ?CLASS(ThisT,wxAuiNotebook),
  wxe_util:queue_cmd(This,Size,?get_env(),?wxAuiNotebook_SetUniformBitmapSize).

-doc "Destroys the object".
-spec destroy(This::wxAuiNotebook()) -> 'ok'.
destroy(Obj=#wx_ref{type=Type}) ->
  ?CLASS(Type,wxAuiNotebook),
  wxe_util:queue_cmd(Obj, ?get_env(), ?DESTROY_OBJECT),
  ok.
 %% From wxControl
-doc false.
setLabel(This,Label) -> wxControl:setLabel(This,Label).
-doc false.
getLabel(This) -> wxControl:getLabel(This).
 %% From wxWindow
-doc false.
getDPI(This) -> wxWindow:getDPI(This).
-doc false.
getContentScaleFactor(This) -> wxWindow:getContentScaleFactor(This).
-doc false.
setDoubleBuffered(This,On) -> wxWindow:setDoubleBuffered(This,On).
-doc false.
isDoubleBuffered(This) -> wxWindow:isDoubleBuffered(This).
-doc false.
canSetTransparent(This) -> wxWindow:canSetTransparent(This).
-doc false.
setTransparent(This,Alpha) -> wxWindow:setTransparent(This,Alpha).
-doc false.
warpPointer(This,X,Y) -> wxWindow:warpPointer(This,X,Y).
-doc false.
validate(This) -> wxWindow:validate(This).
-doc false.
updateWindowUI(This, Options) -> wxWindow:updateWindowUI(This, Options).
-doc false.
updateWindowUI(This) -> wxWindow:updateWindowUI(This).
-doc false.
update(This) -> wxWindow:update(This).
-doc false.
transferDataToWindow(This) -> wxWindow:transferDataToWindow(This).
-doc false.
transferDataFromWindow(This) -> wxWindow:transferDataFromWindow(This).
-doc false.
thaw(This) -> wxWindow:thaw(This).
-doc false.
show(This, Options) -> wxWindow:show(This, Options).
-doc false.
show(This) -> wxWindow:show(This).
-doc false.
shouldInheritColours(This) -> wxWindow:shouldInheritColours(This).
-doc false.
setWindowVariant(This,Variant) -> wxWindow:setWindowVariant(This,Variant).
-doc false.
setWindowStyleFlag(This,Style) -> wxWindow:setWindowStyleFlag(This,Style).
-doc false.
setWindowStyle(This,Style) -> wxWindow:setWindowStyle(This,Style).
-doc false.
setVirtualSize(This,Width,Height) -> wxWindow:setVirtualSize(This,Width,Height).
-doc false.
setVirtualSize(This,Size) -> wxWindow:setVirtualSize(This,Size).
-doc false.
setToolTip(This,TipString) -> wxWindow:setToolTip(This,TipString).
-doc false.
setThemeEnabled(This,Enable) -> wxWindow:setThemeEnabled(This,Enable).
-doc false.
setSizerAndFit(This,Sizer, Options) -> wxWindow:setSizerAndFit(This,Sizer, Options).
-doc false.
setSizerAndFit(This,Sizer) -> wxWindow:setSizerAndFit(This,Sizer).
-doc false.
setSizer(This,Sizer, Options) -> wxWindow:setSizer(This,Sizer, Options).
-doc false.
setSizer(This,Sizer) -> wxWindow:setSizer(This,Sizer).
-doc false.
setSizeHints(This,MinW,MinH, Options) -> wxWindow:setSizeHints(This,MinW,MinH, Options).
-doc false.
setSizeHints(This,MinW,MinH) -> wxWindow:setSizeHints(This,MinW,MinH).
-doc false.
setSizeHints(This,MinSize) -> wxWindow:setSizeHints(This,MinSize).
-doc false.
setSize(This,X,Y,Width,Height, Options) -> wxWindow:setSize(This,X,Y,Width,Height, Options).
-doc false.
setSize(This,X,Y,Width,Height) -> wxWindow:setSize(This,X,Y,Width,Height).
-doc false.
setSize(This,Width,Height) -> wxWindow:setSize(This,Width,Height).
-doc false.
setSize(This,Rect) -> wxWindow:setSize(This,Rect).
-doc false.
setScrollPos(This,Orientation,Pos, Options) -> wxWindow:setScrollPos(This,Orientation,Pos, Options).
-doc false.
setScrollPos(This,Orientation,Pos) -> wxWindow:setScrollPos(This,Orientation,Pos).
-doc false.
setScrollbar(This,Orientation,Position,ThumbSize,Range, Options) -> wxWindow:setScrollbar(This,Orientation,Position,ThumbSize,Range, Options).
-doc false.
setScrollbar(This,Orientation,Position,ThumbSize,Range) -> wxWindow:setScrollbar(This,Orientation,Position,ThumbSize,Range).
-doc false.
setPalette(This,Pal) -> wxWindow:setPalette(This,Pal).
-doc false.
setName(This,Name) -> wxWindow:setName(This,Name).
-doc false.
setId(This,Winid) -> wxWindow:setId(This,Winid).
-doc false.
setHelpText(This,HelpText) -> wxWindow:setHelpText(This,HelpText).
-doc false.
setForegroundColour(This,Colour) -> wxWindow:setForegroundColour(This,Colour).
-doc false.
setFocusFromKbd(This) -> wxWindow:setFocusFromKbd(This).
-doc false.
setFocus(This) -> wxWindow:setFocus(This).
-doc false.
setExtraStyle(This,ExStyle) -> wxWindow:setExtraStyle(This,ExStyle).
-doc false.
setDropTarget(This,Target) -> wxWindow:setDropTarget(This,Target).
-doc false.
setOwnForegroundColour(This,Colour) -> wxWindow:setOwnForegroundColour(This,Colour).
-doc false.
setOwnFont(This,Font) -> wxWindow:setOwnFont(This,Font).
-doc false.
setOwnBackgroundColour(This,Colour) -> wxWindow:setOwnBackgroundColour(This,Colour).
-doc false.
setMinSize(This,Size) -> wxWindow:setMinSize(This,Size).
-doc false.
setMaxSize(This,Size) -> wxWindow:setMaxSize(This,Size).
-doc false.
setCursor(This,Cursor) -> wxWindow:setCursor(This,Cursor).
-doc false.
setContainingSizer(This,Sizer) -> wxWindow:setContainingSizer(This,Sizer).
-doc false.
setClientSize(This,Width,Height) -> wxWindow:setClientSize(This,Width,Height).
-doc false.
setClientSize(This,Size) -> wxWindow:setClientSize(This,Size).
-doc false.
setCaret(This,Caret) -> wxWindow:setCaret(This,Caret).
-doc false.
setBackgroundStyle(This,Style) -> wxWindow:setBackgroundStyle(This,Style).
-doc false.
setBackgroundColour(This,Colour) -> wxWindow:setBackgroundColour(This,Colour).
-doc false.
setAutoLayout(This,AutoLayout) -> wxWindow:setAutoLayout(This,AutoLayout).
-doc false.
setAcceleratorTable(This,Accel) -> wxWindow:setAcceleratorTable(This,Accel).
-doc false.
scrollWindow(This,Dx,Dy, Options) -> wxWindow:scrollWindow(This,Dx,Dy, Options).
-doc false.
scrollWindow(This,Dx,Dy) -> wxWindow:scrollWindow(This,Dx,Dy).
-doc false.
scrollPages(This,Pages) -> wxWindow:scrollPages(This,Pages).
-doc false.
scrollLines(This,Lines) -> wxWindow:scrollLines(This,Lines).
-doc false.
screenToClient(This,Pt) -> wxWindow:screenToClient(This,Pt).
-doc false.
screenToClient(This) -> wxWindow:screenToClient(This).
-doc false.
reparent(This,NewParent) -> wxWindow:reparent(This,NewParent).
-doc false.
removeChild(This,Child) -> wxWindow:removeChild(This,Child).
-doc false.
releaseMouse(This) -> wxWindow:releaseMouse(This).
-doc false.
refreshRect(This,Rect, Options) -> wxWindow:refreshRect(This,Rect, Options).
-doc false.
refreshRect(This,Rect) -> wxWindow:refreshRect(This,Rect).
-doc false.
refresh(This, Options) -> wxWindow:refresh(This, Options).
-doc false.
refresh(This) -> wxWindow:refresh(This).
-doc false.
raise(This) -> wxWindow:raise(This).
-doc false.
popupMenu(This,Menu,X,Y) -> wxWindow:popupMenu(This,Menu,X,Y).
-doc false.
popupMenu(This,Menu, Options) -> wxWindow:popupMenu(This,Menu, Options).
-doc false.
popupMenu(This,Menu) -> wxWindow:popupMenu(This,Menu).
-doc false.
pageUp(This) -> wxWindow:pageUp(This).
-doc false.
pageDown(This) -> wxWindow:pageDown(This).
-doc false.
navigate(This, Options) -> wxWindow:navigate(This, Options).
-doc false.
navigate(This) -> wxWindow:navigate(This).
-doc false.
moveBeforeInTabOrder(This,Win) -> wxWindow:moveBeforeInTabOrder(This,Win).
-doc false.
moveAfterInTabOrder(This,Win) -> wxWindow:moveAfterInTabOrder(This,Win).
-doc false.
move(This,X,Y, Options) -> wxWindow:move(This,X,Y, Options).
-doc false.
move(This,X,Y) -> wxWindow:move(This,X,Y).
-doc false.
move(This,Pt) -> wxWindow:move(This,Pt).
-doc false.
lower(This) -> wxWindow:lower(This).
-doc false.
lineUp(This) -> wxWindow:lineUp(This).
-doc false.
lineDown(This) -> wxWindow:lineDown(This).
-doc false.
layout(This) -> wxWindow:layout(This).
-doc false.
isShownOnScreen(This) -> wxWindow:isShownOnScreen(This).
-doc false.
isTopLevel(This) -> wxWindow:isTopLevel(This).
-doc false.
isShown(This) -> wxWindow:isShown(This).
-doc false.
isRetained(This) -> wxWindow:isRetained(This).
-doc false.
isExposed(This,X,Y,W,H) -> wxWindow:isExposed(This,X,Y,W,H).
-doc false.
isExposed(This,X,Y) -> wxWindow:isExposed(This,X,Y).
-doc false.
isExposed(This,Pt) -> wxWindow:isExposed(This,Pt).
-doc false.
isEnabled(This) -> wxWindow:isEnabled(This).
-doc false.
isFrozen(This) -> wxWindow:isFrozen(This).
-doc false.
invalidateBestSize(This) -> wxWindow:invalidateBestSize(This).
-doc false.
initDialog(This) -> wxWindow:initDialog(This).
-doc false.
inheritAttributes(This) -> wxWindow:inheritAttributes(This).
-doc false.
hide(This) -> wxWindow:hide(This).
-doc false.
hasTransparentBackground(This) -> wxWindow:hasTransparentBackground(This).
-doc false.
hasScrollbar(This,Orient) -> wxWindow:hasScrollbar(This,Orient).
-doc false.
hasCapture(This) -> wxWindow:hasCapture(This).
-doc false.
getWindowVariant(This) -> wxWindow:getWindowVariant(This).
-doc false.
getWindowStyleFlag(This) -> wxWindow:getWindowStyleFlag(This).
-doc false.
getVirtualSize(This) -> wxWindow:getVirtualSize(This).
-doc false.
getUpdateRegion(This) -> wxWindow:getUpdateRegion(This).
-doc false.
getToolTip(This) -> wxWindow:getToolTip(This).
-doc false.
getThemeEnabled(This) -> wxWindow:getThemeEnabled(This).
-doc false.
getTextExtent(This,String, Options) -> wxWindow:getTextExtent(This,String, Options).
-doc false.
getTextExtent(This,String) -> wxWindow:getTextExtent(This,String).
-doc false.
getSizer(This) -> wxWindow:getSizer(This).
-doc false.
getSize(This) -> wxWindow:getSize(This).
-doc false.
getScrollThumb(This,Orientation) -> wxWindow:getScrollThumb(This,Orientation).
-doc false.
getScrollRange(This,Orientation) -> wxWindow:getScrollRange(This,Orientation).
-doc false.
getScrollPos(This,Orientation) -> wxWindow:getScrollPos(This,Orientation).
-doc false.
getScreenRect(This) -> wxWindow:getScreenRect(This).
-doc false.
getScreenPosition(This) -> wxWindow:getScreenPosition(This).
-doc false.
getRect(This) -> wxWindow:getRect(This).
-doc false.
getPosition(This) -> wxWindow:getPosition(This).
-doc false.
getParent(This) -> wxWindow:getParent(This).
-doc false.
getName(This) -> wxWindow:getName(This).
-doc false.
getMinSize(This) -> wxWindow:getMinSize(This).
-doc false.
getMaxSize(This) -> wxWindow:getMaxSize(This).
-doc false.
getId(This) -> wxWindow:getId(This).
-doc false.
getHelpText(This) -> wxWindow:getHelpText(This).
-doc false.
getHandle(This) -> wxWindow:getHandle(This).
-doc false.
getGrandParent(This) -> wxWindow:getGrandParent(This).
-doc false.
getForegroundColour(This) -> wxWindow:getForegroundColour(This).
-doc false.
getFont(This) -> wxWindow:getFont(This).
-doc false.
getExtraStyle(This) -> wxWindow:getExtraStyle(This).
-doc false.
getDPIScaleFactor(This) -> wxWindow:getDPIScaleFactor(This).
-doc false.
getDropTarget(This) -> wxWindow:getDropTarget(This).
-doc false.
getCursor(This) -> wxWindow:getCursor(This).
-doc false.
getContainingSizer(This) -> wxWindow:getContainingSizer(This).
-doc false.
getClientSize(This) -> wxWindow:getClientSize(This).
-doc false.
getChildren(This) -> wxWindow:getChildren(This).
-doc false.
getCharWidth(This) -> wxWindow:getCharWidth(This).
-doc false.
getCharHeight(This) -> wxWindow:getCharHeight(This).
-doc false.
getCaret(This) -> wxWindow:getCaret(This).
-doc false.
getBestSize(This) -> wxWindow:getBestSize(This).
-doc false.
getBackgroundStyle(This) -> wxWindow:getBackgroundStyle(This).
-doc false.
getBackgroundColour(This) -> wxWindow:getBackgroundColour(This).
-doc false.
getAcceleratorTable(This) -> wxWindow:getAcceleratorTable(This).
-doc false.
freeze(This) -> wxWindow:freeze(This).
-doc false.
fitInside(This) -> wxWindow:fitInside(This).
-doc false.
fit(This) -> wxWindow:fit(This).
-doc false.
findWindow(This,Id) -> wxWindow:findWindow(This,Id).
-doc false.
enable(This, Options) -> wxWindow:enable(This, Options).
-doc false.
enable(This) -> wxWindow:enable(This).
-doc false.
dragAcceptFiles(This,Accept) -> wxWindow:dragAcceptFiles(This,Accept).
-doc false.
disable(This) -> wxWindow:disable(This).
-doc false.
destroyChildren(This) -> wxWindow:destroyChildren(This).
-doc false.
convertPixelsToDialog(This,Sz) -> wxWindow:convertPixelsToDialog(This,Sz).
-doc false.
convertDialogToPixels(This,Sz) -> wxWindow:convertDialogToPixels(This,Sz).
-doc false.
close(This, Options) -> wxWindow:close(This, Options).
-doc false.
close(This) -> wxWindow:close(This).
-doc false.
clientToScreen(This,X,Y) -> wxWindow:clientToScreen(This,X,Y).
-doc false.
clientToScreen(This,Pt) -> wxWindow:clientToScreen(This,Pt).
-doc false.
clearBackground(This) -> wxWindow:clearBackground(This).
-doc false.
centreOnParent(This, Options) -> wxWindow:centreOnParent(This, Options).
-doc false.
centerOnParent(This, Options) -> wxWindow:centerOnParent(This, Options).
-doc false.
centreOnParent(This) -> wxWindow:centreOnParent(This).
-doc false.
centerOnParent(This) -> wxWindow:centerOnParent(This).
-doc false.
centre(This, Options) -> wxWindow:centre(This, Options).
-doc false.
center(This, Options) -> wxWindow:center(This, Options).
-doc false.
centre(This) -> wxWindow:centre(This).
-doc false.
center(This) -> wxWindow:center(This).
-doc false.
captureMouse(This) -> wxWindow:captureMouse(This).
-doc false.
cacheBestSize(This,Size) -> wxWindow:cacheBestSize(This,Size).
 %% From wxEvtHandler
-doc false.
disconnect(This,EventType, Options) -> wxEvtHandler:disconnect(This,EventType, Options).
-doc false.
disconnect(This,EventType) -> wxEvtHandler:disconnect(This,EventType).
-doc false.
disconnect(This) -> wxEvtHandler:disconnect(This).
-doc false.
connect(This,EventType, Options) -> wxEvtHandler:connect(This,EventType, Options).
-doc false.
connect(This,EventType) -> wxEvtHandler:connect(This,EventType).
